#ifndef NT2_INCLUDE_CONSTANTS_SQRT_1O_5_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SQRT_1O_5_HPP_INCLUDED

#include <nt2/constant/include/constants/sqrt_1o_5.hpp>

#endif
